==> ejc-panhuo-api-3.0.0-20231220.011435-186-sources.jar: com/ejianc/business/panhuo/vo/PutawayVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.panhuo.vo.PutawayDetailVO;

/**
 * 批量上架
 * 
 * @author generator
 * 
 */
public class PutawayVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 资产编号
    private Long seller; // 发布人
    private String sellerName; // 发布人名称
    private Long projectId; // 项目主键
    private Long orgId; // 组织主键
    private String projectName; // 项目名称
    private String orgName; // 组织名称
    private Long addressId; // 地址主键
    private String addressName; // 出售项目
    private String projectAddress; // 
    private String address; // 详细地址
    private String firstLocation; // 所在地一级区域
    private String secondLocation; // 所在地二级区域
    private String thirdLocation; // 所在地三级区域
    private String fourthLocation; // 所在地四级区域
    private String location; // 所在地末级区域
    private Double lon; // 经度
    private Double lat; // 纬度
    private String phone; // 联系方式
    private String name; // 联系人
    private String memo; // 备注
    private List<PutawayDetailVO> putawayDetailList = new ArrayList<>(); // 批量上架子表

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getSeller() {
        return seller;
    }

    public void setSeller(Long seller) {
        this.seller = seller;
    }
    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getAddressName() {
        return addressName;
    }

    public void setAddressName(String addressName) {
        this.addressName = addressName;
    }
    public String getProjectAddress() {
        return projectAddress;
    }

    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getFirstLocation() {
        return firstLocation;
    }

    public void setFirstLocation(String firstLocation) {
        this.firstLocation = firstLocation;
    }
    public String getSecondLocation() {
        return secondLocation;
    }

    public void setSecondLocation(String secondLocation) {
        this.secondLocation = secondLocation;
    }
    public String getThirdLocation() {
        return thirdLocation;
    }

    public void setThirdLocation(String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    public String getFourthLocation() {
        return fourthLocation;
    }

    public void setFourthLocation(String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    public String getLocation() {
        return location;
    }

    public void setLocation(String location) {
        this.location = location;
    }
    public Double getLon() {
        return lon;
    }

    public void setLon(Double lon) {
        this.lon = lon;
    }
    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

     public List<PutawayDetailVO> getPutawayDetailList() {
        return putawayDetailList;
     }

     public void setPutawayDetailList(List<PutawayDetailVO> putawayDetailList) {
        this.putawayDetailList = putawayDetailList;
     }
    /**
     * 地址主键
     */
    @ReferSerialTransfer(referCode="panhuo-addressRef")
    public java.lang.Long getAddressId() {
        return addressId;
    }

    /**
     * 地址主键
     */
    @ReferDeserialTransfer
    public void setAddressId(java.lang.Long addressId) {
        this.addressId = addressId;
    }
}

==> ejc-panhuo-api-3.0.0-20231225.072654-198-sources.jar: com/ejianc/business/panhuo/vo/PutawayVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.panhuo.vo.PutawayDetailVO;

/**
 * 批量上架
 * 
 * @author generator
 * 
 */
public class PutawayVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 资产编号
    private Long seller; // 发布人
    private String sellerName; // 发布人名称
    private Long projectId; // 项目主键
    private Long orgId; // 组织主键
    private String projectName; // 项目名称
    private String orgName; // 组织名称
    private Long addressId; // 地址主键
    private String addressName; // 出售项目
    private String projectAddress; // 
    private String address; // 详细地址
    private String firstLocation; // 所在地一级区域
    private String secondLocation; // 所在地二级区域
    private String thirdLocation; // 所在地三级区域
    private String fourthLocation; // 所在地四级区域
    private String location; // 所在地末级区域
    private Double lon; // 经度
    private Double lat; // 纬度
    private String phone; // 联系方式
    private String name; // 联系人
    private String memo; // 备注
    private String materialNames; // 物料名称合计
    private BigDecimal sumShelfMny; // 上架金额汇总
    private String billStateName; //
    private Integer billState; //

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    private List<PutawayDetailVO> putawayDetailList = new ArrayList<>(); // 批量上架子表

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public BigDecimal getSumShelfMny() {
        return sumShelfMny;
    }

    public void setSumShelfMny(BigDecimal sumShelfMny) {
        this.sumShelfMny = sumShelfMny;
    }

    public String getMaterialNames() {
        return materialNames;
    }

    public void setMaterialNames(String materialNames) {
        this.materialNames = materialNames;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getSeller() {
        return seller;
    }

    public void setSeller(Long seller) {
        this.seller = seller;
    }
    public String getSellerName() {
        return sellerName;
    }

    public void setSellerName(String sellerName) {
        this.sellerName = sellerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getAddressName() {
        return addressName;
    }

    public void setAddressName(String addressName) {
        this.addressName = addressName;
    }
    public String getProjectAddress() {
        return projectAddress;
    }

    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getFirstLocation() {
        return firstLocation;
    }

    public void setFirstLocation(String firstLocation) {
        this.firstLocation = firstLocation;
    }
    public String getSecondLocation() {
        return secondLocation;
    }

    public void setSecondLocation(String secondLocation) {
        this.secondLocation = secondLocation;
    }
    public String getThirdLocation() {
        return thirdLocation;
    }

    public void setThirdLocation(String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    public String getFourthLocation() {
        return fourthLocation;
    }

    public void setFourthLocation(String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    public String getLocation() {
        return location;
    }

    public void setLocation(String location) {
        this.location = location;
    }
    public Double getLon() {
        return lon;
    }

    public void setLon(Double lon) {
        this.lon = lon;
    }
    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

     public List<PutawayDetailVO> getPutawayDetailList() {
        return putawayDetailList;
     }

     public void setPutawayDetailList(List<PutawayDetailVO> putawayDetailList) {
        this.putawayDetailList = putawayDetailList;
     }
    /**
     * 地址主键
     */
    @ReferSerialTransfer(referCode="panhuo-addressRef")
    public java.lang.Long getAddressId() {
        return addressId;
    }

    /**
     * 地址主键
     */
    @ReferDeserialTransfer
    public void setAddressId(java.lang.Long addressId) {
        this.addressId = addressId;
    }
}
